package utils;

import java.io.PrintStream;

public class Timer {
    private long baseTime;
    private long elapsedTime;

    private static final long UNIT = 1000;

    public Timer() {
        clear();
    }
    /**
     * record the current time in milliseconds
     * at the start point.
     */
    public void start() {
        baseTime = System.currentTimeMillis();
    }
    /**
     * Zero the elapsedTime
     */
    public void clear() {
        elapsedTime = 0;
    }
    /**
     * Compute the difference between the mark'd time
     * and the current time, in milliseconds.
     * The record method computes the elapsed_time.
     *
     */
    public void stop() {
        elapsedTime = (System.currentTimeMillis() - baseTime);
    }
    /**
     * This is the time between a mark and a record.
     * @return the time in seconds as a float
     */
    public double getElapsedTime() {
        return ((float) elapsedTime) / UNIT;
    }

    public void report(PrintStream ps) {
        double elapsed_seconds = getElapsedTime();
        ps.println("Time " + elapsed_seconds + " sec");
    }

    public static void main(String[] args) {
        Timer t = new Timer();
        t.start();
        double j = Math.PI;
        int n = 10000000;
        for (int i=0; i < n; i++){
            j /= Math.E;
        }
        t.stop();
        double f = t.getElapsedTime();
        double flops = n / f;
        System.out.println("you machine is running at "+flops/1000000 +" mflops");
    }
    /**
     * Report the elapsed time between the mark and the record
     * invocations to the <code>System.out</code>.
     */
    public void report() {
        report(System.out);
    }

    public double getTime() {
        return getElapsedTime();
    }

    public void print(int N, String message) {
        System.out.println(
                message
                + " "
                + getTime() + " seconds "
                + N / getTime() + "  per second");
        start();
    }

    public void print(String message) {

        System.out.println(
                message
                + " "
                + getTime() + " seconds "
        );
        start();
    }

}

